@@ -31,15 +31,15 @@ SELECTION_REQUEST = 18
 SELECTION_NOTIFY  = 19
 PROXIMITY_IN      = 20
 PROXIMITY_OUT     = 21
-DRAG_BEGIN        = 22
-DRAG_REQUEST      = 23
-DROP_ENTER        = 24
-DROP_LEAVE        = 25
-DROP_DATA_AVAIL   = 26
-CLIENT_EVENT      = 27
-VISIBILITY_NOTIFY = 28
+DRAG_ENTER        = 22
+DRAG_LEAVE        = 23
+DRAG_MOTION       = 24
+DRAG_STATUS       = 25
+DROP_START        = 26
+DROP_FINISHED     = 27
+CLIENT_EVENT      = 28
+VISIBILITY_NOTIFY = 29
 NO_EXPOSE         = 30
-OTHER_EVENT       = 9999
 
 # GdkEventMask's
 EXPOSURE_MASK            = 1 << 1
@@ -106,19 +106,18 @@ PROP_MODE_REPLACE = 0
 PROP_MODE_PREPEND = 1
 PROP_MODE_APPEND  = 2
 
-# GdkDndType's
-DNDTYPE_NOTDND  = -1
-DNDTYPE_UNKNOWN = 0
-DNDTYPE_RAWDATA = 1
-DNDTYPE_FILE    = 2
-DNDTYPE_FILES   = 3
-DNDTYPE_TEXT    = 4
-DNDTYPE_DIR     = 5
-DNDTYPE_LINK    = 6
-DNDTYPE_EXE     = 7
-DNDTYPE_URL     = 8
-DNDTYPE_MIME    = 9
-DNDTYPE_END     = 10
+# GdkDragAction's
+ACTION_DEFAULT = 1 << 0
+ACTION_COPY    = 1 << 1
+ACTION_MOVE    = 1 << 2
+ACTION_LINK    = 1 << 3
+ACTION_PRIVATE = 1 << 4
+ACTION_ASK     = 1 << 5
+
+# GdkDragProtocol's
+DRAG_PROTO_MOTIF   = 0
+DRAG_PROTO_XDND    = 1
+DRAG_PROTO_ROOTWIN = 2
 
 # GdkSelectionType's
 SELECTION_TYPE_ATOM     = 4
@@ -167,9 +166,21 @@ VISIBILITY_PARTIAL        = 1
 VISIBILITY_FULLY_OBSCURED = 2
 
 # GdkFunction's
-COPY   = 0
-INVERT = 1
-XOR    = 2
+COPY        = 0
+INVERT      = 1
+XOR         = 2
+CLEAR       = 3
+AND         = 4
+AND_REVERSE = 5
+AND_INVERT  = 6
+NOOP        = 7
+OR          = 8
+EQUIV       = 9
+OR_REVERSE  = 10
+COPY_INVERT = 11
+OR_INVERT   = 12
+NAND        = 13
+SET         = 14
 
 # GdkFill's
 SOLID           = 0
@@ -197,6 +208,92 @@ JOIN_MITER = 0
 JOIN_ROUND = 1
 JOIN_BEVEL = 2
 
+# GdkRgbDither's
+RGB_DITHER_NONE   = 0
+RGB_DITHER_NORMAL = 1
+RGB_DITHER_MAX    = 2
+
+# GdkCursorType's
+X_CURSOR = 0
+ARROW = 2
+BASED_ARROW_DOWN = 4
+BASED_ARROW_UP = 6
+BOAT = 8
+BOGOSITY = 10
+BOTTOM_LEFT_CORNER = 12
+BOTTOM_RIGHT_CORNER = 14
+BOTTOM_SIDE = 16
+BOTTOM_TEE = 18
+BOX_SPIRAL = 20
+CENTER_PTR = 22
+CIRCLE = 24
+CLOCK = 26
+COFFEE_MUG = 28
+CROSS = 30
+CROSS_REVERSE = 32
+CROSSHAIR = 34
+DIAMOND_CROSS = 36
+DOT = 38
+DOTBOX = 40
+DOUBLE_ARROW = 42
+DRAFT_LARGE = 44
+DRAFT_SMALL = 46
+DRAPED_BOX = 48
+EXCHANGE = 50
+FLEUR = 52
+GOBBLER = 54
+GUMBY = 56
+HAND1 = 58
+HAND2 = 60
+HEART = 62
+ICON = 64
+IRON_CROSS = 66
+LEFT_PTR = 68
+LEFT_SIDE = 70
+LEFT_TEE = 72
+LEFTBUTTON = 74
+LL_ANGLE = 76
+LR_ANGLE = 78
+MAN = 80
+MIDDLEBUTTON = 82
+MOUSE = 84
+PENCIL = 86
+PIRATE = 88
+PLUS = 90
+QUESTION_ARROW = 92
+RIGHT_PTR = 94
+RIGHT_SIDE = 96
+RIGHT_TEE = 98
+RIGHTBUTTON = 100
+RTL_LOGO = 102
+SAILBOAT = 104
+SB_DOWN_ARROW = 106
+SB_H_DOUBLE_ARROW = 108
+SB_LEFT_ARROW = 110
+SB_RIGHT_ARROW = 112
+SB_UP_ARROW = 114
+SB_V_DOUBLE_ARROW = 116
+SHUTTLE = 118
+SIZING = 120
+SPIDER = 122
+SPRAYCAN = 124
+STAR = 126
+TARGET = 128
+TCROSS = 130
+TOP_LEFT_ARROW = 132
+TOP_LEFT_CORNER = 134
+TOP_RIGHT_CORNER = 136
+TOP_SIDE = 138
+TOP_TEE = 140
+TREK = 142
+UL_ANGLE = 144
+UMBRELLA = 146
+UR_ANGLE = 148
+WATCH = 150
+XTERM = 152
+CURSOR_IS_PIXMAP = -1
+
+
 # these are the Key Symbols for GDK
 # they were created with sed -n 's/#define GDK)\([^ ]*\)/\1 =/p' <gdkkeysyms.h
 VoidSymbol = 0xFFFFFF
