@@ -15,7 +15,7 @@
 
 import _gdkimlib
 
-from Gtkinter import _obj2inst
+from Gtkinter import GtkPixmap
 
 #some constants ...
 RT_PLAIN_PALETTE       = 0
@@ -110,8 +110,23 @@ class Image:
 		_gdkimlib.gdk_imlib_crop_image(self._im, x, y, w, h)
 	def save_image(self, file):
 		return _gdkimlib.gdk_imlib_save_image(self._im, file)
+	def crop_and_clone_image(self, x, y, w, h):
+		return Image(_obj=_gdkimlib.gdk_imlib_crop_and_clone_image(
+			self._im, x, y, w, h)
 	def make_pixmap(self):
-		return _obj2inst(_gdkimlib.gdk_imlib_make_pixmap(self._im))
+		return GtkPixmap(_obj=
+				 _gdkimlib.gdk_imlib_make_pixmap(self._im))
+	def get_pixmap(self):
+		return _gdkimlib.gdk_imlib_get_pixmap(self._im)
+
+def create_image_from_data(data, alpha, width, height):
+	# alpha can be None
+	return Image(_obj=_gdkimlib.gdk_imlib_create_image_from_data(
+		data, alpha, width, height))
+
+def create_image_from_drawable(drawable, mask, x, y, width, height):
+	return Image(_obj=_gdkimlib.gdk_imlib_create_image_from_drawable(
+		drawable, mask, x, y, width, height))
 
 def get_render_type():
 	return _gdkimlib.gdk_imlib_get_render_type()
