@@ -6,7 +6,6 @@
 #
 # TODO
 # 1. document some of this (maybe all of it)
-# 2. fix up GtkImage (no one has needed it yet so it is low priority)
 
 # The _obj argument in each constructor is used to create a Gtkinter object
 # that coresponds to an already created GTK Object.  It should be possible
@@ -19,38 +18,36 @@
 
 from GTK import *
 import GDK    # make the GDK constants available
-import _gtk, _gtkbase
+import _gtk
 import sys, os
 
 # this sets up i18n input stuff
-_gtkbase.gtk_set_locale()
+_gtk.gtk_set_locale()
 
 # initialise GTK (only if it can find the display -- this avoids segfaults)
 if '--display' in sys.argv or os.environ.has_key('DISPLAY'):
-	_gtkbase.gtk_init()
-	# this makes the _gtk module aware of the types and funcs in _gtkbase
-	_gtk.pygtk_init()
+	_gtk.gtk_init()
 else:
 	print 'No display information -- gtk_init not called'
 del sys, os
 
 class GtkObject:
-	get_type = _gtkbase.gtk_object_get_type
+	get_type = _gtk.gtk_object_get_type
 	def __init__(self, _obj=None):
 		if _obj: self._o = _obj; return
 	def set(self, dict):
 		_filtprops(dict)
-		_gtkbase.gtk_object_set(self._o, dict)
+		_gtk.gtk_object_set(self._o, dict)
 	def __getitem__(self, key):
-		ret = _gtkbase.gtk_object_get(self._o, key)
-		if type(ret) == _gtkbase.GtkObjectType:
+		ret = _gtk.gtk_object_get(self._o, key)
+		if type(ret) == _gtk.GtkObjectType:
 			return _obj2inst(ret)
 		else:
 			return ret
 	def __setitem__(self, key, v):
-		if hasattr(v, '_o') and type(v._o) == _gtkbase.GtkObjectType:
+		if hasattr(v, '_o') and type(v._o) == _gtk.GtkObjectType:
 			v = v._o
-		_gtkbase.gtk_object_set(self._o, {key: v});
+		_gtk.gtk_object_set(self._o, {key: v});
 	def __cmp__(self, other):
 	        if hasattr(other, '_o'):
 			return cmp(self._o, other._o)
@@ -58,56 +55,60 @@ class GtkObject:
 			return cmp(id(self), id(other))
 	def flags(self, mask=None):
 		if mask:
-			return _gtkbase.GTK_OBJECT_FLAGS(self._o) & mask
+			return _gtk.GTK_OBJECT_FLAGS(self._o) & mask
 		else:
-			return _gtkbase.GTK_OBJECT_FLAGS(self._o)
+			return _gtk.GTK_OBJECT_FLAGS(self._o)
 	def set_flags(self, flags):
-		_gtkbase.GTK_OBJECT_SET_FLAGS(self._o, flags)
+		_gtk.GTK_OBJECT_SET_FLAGS(self._o, flags)
 	def unset_flags(self, flags):
-		_gtkbase.GTK_OBJECT_UNSET_FLAGS(self._o, flags)
+		_gtk.GTK_OBJECT_UNSET_FLAGS(self._o, flags)
 	def set_data(self, key, value):
-		_gtkbase.gtk_object_set_data(self._o, key, value)
+		_gtk.gtk_object_set_data(self._o, key, value)
 	def get_data(self, key):
-		return _gtkbase.gtk_object_get_data(self._o, key)
+		return _gtk.gtk_object_get_data(self._o, key)
 	def remove_data(self, key):
-		_gtkbase.gtk_object_remove_data(self._o)
+		_gtk.gtk_object_remove_data(self._o)
 	class __cnv:
 		def __init__(self, func):
 			self.func = func
 		def __call__(self, *args):
 			a = list(args)
 			for i in range(len(args)):
-				if type(args[i]) == _gtkbase.GtkObjectType:
+				if type(args[i]) == _gtk.GtkObjectType:
 					a[i] = _obj2inst(args[i])
 			a = tuple(a)
-			return apply(self.func, a)
+			ret = apply(self.func, a)
+			if hasattr(ret, '_o'): ret = ret._o
+			return ret
 	def connect(self, name, f, *extra):
 		callback = self.__cnv(f)
-		return _gtkbase.gtk_signal_connect(self._o, name,
+		return _gtk.gtk_signal_connect(self._o, name,
 						   callback.__call__, extra)
 	signal_connect = connect
 	def connect_after(self, name, f, *extra):
 		callback = self.__cnv(f)
-		return _gtkbase.gtk_signal_connect_after(self._o, name,
+		return _gtk.gtk_signal_connect_after(self._o, name,
 						     callback.__call__, extra)
 	signal_connect_after = connect_after
 	def disconnect(self, id):
-		_gtkbase.gtk_signal_disconnect(self._o, id)
+		_gtk.gtk_signal_disconnect(self._o, id)
 	def signal_handler_block(self, id):
-		_gtkbase.gtk_signal_handler_block(self._o, id)
+		_gtk.gtk_signal_handler_block(self._o, id)
 	def signal_handler_unblock(self, id):
-		_gtkbase.gtk_signal_handler_unblock(self._o, id)
+		_gtk.gtk_signal_handler_unblock(self._o, id)
 	def signal_handlers_destroy(self):
-		_gtkbase.gtk_signal_handlers_destroy(self._o)
+		_gtk.gtk_signal_handlers_destroy(self._o)
 	def emit(self, signal, *args):
 		params = []
 		for i in args:
 			if hasattr(i, '_o'): params.append(i._o)
 			elif hasattr(i, '_ag'): params.append(i._ag)
 			else: params.append(i)
-		return _gtkbase.gtk_signal_emitv_by_name(self._o,signal,params)
+		return _gtk.gtk_signal_emitv_by_name(self._o,signal,params)
 	def emit_stop_by_name(self, sig):
-		_gtkbase.gtk_signal_emit_stop_by_name(self._o, sig)
+		_gtk.gtk_signal_emit_stop_by_name(self._o, sig)
+	def destroy(self, _obj=None):
+		_gtk.gtk_object_destroy(self._o)
 
 class GtkData(GtkObject):
 	get_type = _gtk.gtk_data_get_type
@@ -160,6 +161,8 @@ class GtkTooltips(GtkData):
 		self.set_tip(w, tip, tip)
 	def set_colors(self, back, fore):
 		_gtk.gtk_tooltips_set_colors(self._o, back, fore)
+	def force_window(self):
+		_gtk.gtk_tooltips_force_window(self._o)
 
 class GtkItemFactory(GtkObject):
 	get_type = _gtk.gtk_item_factory_get_type
@@ -196,186 +199,225 @@ class GtkItemFactory(GtkObject):
 		_gtk.gtk_item_factory_popup(self._o, x, y, button, time)
 
 class GtkWidget(GtkObject):
-	get_type = _gtkbase.gtk_widget_get_type
+	get_type = _gtk.gtk_widget_get_type
 	def __init__(self, _obj=None):
 		if _obj: self._o = _obj; return
 	# extra parameter is so that these funcs can be used as signal funcs
 	def activate(self, obj=None):
-		_gtkbase.gtk_widget_activate(self._o)
+		_gtk.gtk_widget_activate(self._o)
 	def add_accelerator(self, signal, group, key, mods, flags):
-		_gtkbase.gtk_widget_add_accelerator(self._o, signal, group._ag,
+		_gtk.gtk_widget_add_accelerator(self._o, signal, group._ag,
 						key, mods, flags)
 	def basic(self, obj=None):
-		_gtkbase.gtk_widget_basic(self._o)
+		_gtk.gtk_widget_basic(self._o)
 	def destroy(self, obj=None):
-		_gtkbase.gtk_widget_destroy(self._o)
-	def dnd_drag_add(self, obj=None):
-		_gtkbase.gtk_widget_dnd_add(self._o)
-	def dnd_drag_set(self, enable, types):
-		_gtkbase.gtk_widget_dnd_drag_set(self._o, enable, types)
-	def dnd_drop_set(self, enable, types, destructive):
-		_gtkbase.gtk_widget_dnd_drop_set(self._o, enable, types,
-					     destructive)
-	def dnd_data_set(self, event, data):
-		_gtkbase.gtk_widget_dnd_data_set(self._o, event, data)
+		_gtk.gtk_widget_destroy(self._o)
+	def drag_get_data(self, context, target, time):
+		_gtk.gtk_drag_get_data(self._o, context, target, time)
+	def drag_finish(self, context, success, delete, time):
+		_gtk.gtk_drag_finish(context, success, delete, time)
+	def drag_highlight(self):
+		_gtk.gtk_drag_highlight(self._o)
+	def drag_unhighlight(self):
+		_gtk.gtk_drag_unhighlight(self._o)
+	# targets is a list of 3-tuples of form
+	# (string target, int flags ,int info)
+	def drag_dest_set(self, flags, targets, actions):
+		_gtk.gtk_drag_dest_set(self._o, flags, targets, actions)
+	def drag_dest_set_proxy(self, proxy_window, protocol, use_coordinates):
+		_gtk.gtk_drag_dest_set_proxy(self._o, proxy_window, protocol,
+					     use_coordinates)
+	def drag_dest_unset(self):
+		_gtk.gtk_drag_dest_unset(self._o)
+	# targets as for drag_dest_set
+	def drag_source_set(self, button_mask, targets, actions):
+		_gtk.gtk_drag_source_set(self._o, button_mask, targets,actions)
+	def drag_source_set_icon(self, colormap, pixmap, mask):
+		_gtk.gtk_drag_source_set_icon(self._o, colormap, pixmap, mask)
+	# targets as for drag_dest_set
+	def drag_begin(self, targets, actions, button, event):
+		return _gtk.gtk_drag_begine(self._o, targets, actions, button,
+					    event)
+	def drag_set_icon_widget(self, context, widget, hot_x, hot_y):
+		_gtk.gtk_drag_set_icon_widget(context, widget._o, hot_x, hot_y)
+	def drag_set_icon_pixmap(self, context, colormap, pixmap, mask,
+				 hot_x, hot_y):
+		_gtk.gtk_drag_set_icon_pixmap(context, colormap, pixmap, mask,
+					      hot_x, hot_y)
+	def drag_set_icon_default(self, context):
+		_gtk.gtk_drag_set_icon_default(context)
+	def drag_set_default_icon(self, colormap, pixmap, mask, hot_x, hot_y):
+		_gtk.gtk_drag_set_default_icon(colormap, pixmap, mask,
+					       hot_x, hot_y)
 	def draw(self, rect):
-		_gtkbase.gtk_widget_draw(self._o, rect)
+		_gtk.gtk_widget_draw(self._o, rect)
 	def draw_children(self, obj=None):
-		_gtkbase.gtk_widget_draw_children(self._o)
+		_gtk.gtk_widget_draw_children(self._o)
 	def draw_default(self, obj=None):
-		_gtkbase.gtk_widget_draw_default(self._o)
+		_gtk.gtk_widget_draw_default(self._o)
 	def draw_focus(self, obj=None):
-		_gtkbase.gtk_widget_draw_focus(self._o)
+		_gtk.gtk_widget_draw_focus(self._o)
 	def ensure_style(self):
-		_gtkbase.gtk_widget_ensure_style(self._o)
+		_gtk.gtk_widget_ensure_style(self._o)
 	def event(self, event):
-		_gtkbase.gtk_widget_event
+		_gtk.gtk_widget_event
 	def freeze_accelerators(self):
-		_gtkbase.gtk_widget_freeze_accelerators(self._o)
+		_gtk.gtk_widget_freeze_accelerators(self._o)
 	def get_ancestor(self, type):
-		return _obj2inst(_gtkbase.gtk_widget_get_ancestor(self._o, type))
+		return _obj2inst(_gtk.gtk_widget_get_ancestor(self._o, type))
 	def get_events(self):
-		return _gtkbase.gtk_widget_get_events(self._o)
+		return _gtk.gtk_widget_get_events(self._o)
 	def get_extension_events(self):
-		return _gtkbase.gtk_widget_get_extension_events(self._o)
+		return _gtk.gtk_widget_get_extension_events(self._o)
 	def get_name(self):
-		return _gtkbase.gtk_widget_get_name(self._o)
+		return _gtk.gtk_widget_get_name(self._o)
 	def get_parent_window(self):
-		return _gtkbase.gtk_widget_get_parent_window(self._o)
+		return _gtk.gtk_widget_get_parent_window(self._o)
 	def get_pointer(self):
-		return _gtkbase.gtk_widget_get_pointer(self._o)
+		return _gtk.gtk_widget_get_pointer(self._o)
 	def get_style(self):
-		return _gtkbase.gtk_widget_get_style(self._o)
+		return _gtk.gtk_widget_get_style(self._o)
 	def get_toplevel(self):
-		return _obj2inst(_gtkbase.gtk_widget_get_toplevel(self._o))
+		return _obj2inst(_gtk.gtk_widget_get_toplevel(self._o))
 	def get_window(self):
-		return _gtkbase.gtk_widget_get_window(self._o)
+		return _gtk.gtk_widget_get_window(self._o)
 	def grab_focus(self, obj=None):
-		_gtkbase.gtk_widget_grab_focus(self._o)
+		_gtk.gtk_widget_grab_focus(self._o)
 	def grab_default(self, obj=None):
-		_gtkbase.gtk_widget_grab_default(self._o)
+		_gtk.gtk_widget_grab_default(self._o)
 	def hide(self, obj=None):
-		_gtkbase.gtk_widget_hide(self._o)
+		_gtk.gtk_widget_hide(self._o)
 	def hide_all(self, obj=None):
-		_gtkbase.gtk_widget_hide_all(self._o)
+		_gtk.gtk_widget_hide_all(self._o)
 	def hide_on_delete(self, obj=None):
-		return _gtkbase.gtk_widget_hide_on_delete(self._o)
+		return _gtk.gtk_widget_hide_on_delete(self._o)
 	def intersect(self, rect):
-		return _gtkbase.gtk_widget_intersect(self._o, rect)
+		return _gtk.gtk_widget_intersect(self._o, rect)
 	def is_ancestor(self, a):
-		return _gtkbase.gtk_widget_is_ancestor(self._o, a._o)
+		return _gtk.gtk_widget_is_ancestor(self._o, a._o)
 	def is_child(self, c):
-		return _gtkbase.gtk_widget_is_child(self._o, c._o)
+		return _gtk.gtk_widget_is_child(self._o, c._o)
 	def map(self, obj=None):
-		_gtkbase.gtk_widget_map(self._o)
+		_gtk.gtk_widget_map(self._o)
 	def popup(self, x, y):
-		_gtkbase.gtk_widget_popup(self._o, x, y)
+		_gtk.gtk_widget_popup(self._o, x, y)
 	def queue_draw(self, obj=None):
-		_gtkbase.gtk_widget_queue_draw(self._o)
+		_gtk.gtk_widget_queue_draw(self._o)
 	def queue_resize(self, obj=None):
-		_gtkbase.gtk_widget_queue_resize(self._o)
+		_gtk.gtk_widget_queue_resize(self._o)
 	def realize(self, obj=None):
-		_gtkbase.gtk_widget_realize(self._o)
+		_gtk.gtk_widget_realize(self._o)
 	def remove_accelerator(self, group, key, mods):
-		_gtkbase.gtk_widget_remove_accelerator(self._o, group._ag,
+		_gtk.gtk_widget_remove_accelerator(self._o, group._ag,
 						   key, mods)
 	def remove_accelerators(self, signal, visible_only):
-		_gtkbase.gtk_widget_remove_accelerators(self._o, signal,
+		_gtk.gtk_widget_remove_accelerators(self._o, signal,
 						    visible_only)
 	def reparent(self, new_parent):
-		_gtkbase.gtk_widget_reparent(self._o, new_parent._o)
+		_gtk.gtk_widget_reparent(self._o, new_parent._o)
 	def reset_rc_styles(self):
-		_gtkbase.gtk_widget_reset_rc_styles(self._o)
+		_gtk.gtk_widget_reset_rc_styles(self._o)
 	def restore_default_style(self):
-		_gtkbase.gtk_widget_restore_default_style(self._o)
+		_gtk.gtk_widget_restore_default_style(self._o)
+	def selection_owner_set(self, selection, time):
+		return _gtk.gtk_selection_owner_set(self._o, selection, time)
+	def selection_add_target(self, selection, target, info):
+		_gtk.gtk_selection_add_target(self._o, selection, target, info)
+	def selection_convert(self, selection, target, time):
+		return _gtk.gtk_selection_convert(self._o, selection,
+						  target, time)
+	def selection_remove_all(self):
+		_gtk.gtk_selection_remove_all(self._o)
 	def set_events(self, events):
-		_gtkbase.gtk_widget_set_events(self._o, events)
+		_gtk.gtk_widget_set_events(self._o, events)
+	def add_events(self, events):
+		_gtk.gtk_widget_add_events(self._o, events)
 	def set_extension_events(self, exevents):
-		_gtkbase.gtk_widget_set_extension_events(self._o, exevents)
+		_gtk.gtk_widget_set_extension_events(self._o, exevents)
 	def set_name(self, name):
-		_gtkbase.gtk_widget_set_name(self._o, name)
+		_gtk.gtk_widget_set_name(self._o, name)
 	def set_parent(self, parent):
-		_gtkbase.gtk_widget_set_parent(self._o, parent._o)
+		_gtk.gtk_widget_set_parent(self._o, parent._o)
 	def set_parent_window(self, parent):
-		_gtkbase.gtk_widget_set_parent_window(self._o, parent)
+		_gtk.gtk_widget_set_parent_window(self._o, parent)
 	def set_sensitive(self, s):
-		_gtkbase.gtk_widget_set_sensitive(self._o, s)
+		_gtk.gtk_widget_set_sensitive(self._o, s)
 	def set_state(self, s):
-		_gtkbase.gtk_widget_set_state(self._o, s)
+		_gtk.gtk_widget_set_state(self._o, s)
 	def set_style(self, style):
-		_gtkbase.gtk_widget_set_style(self._o, style)
+		_gtk.gtk_widget_set_style(self._o, style)
 	def set_rc_style(self):
-		_gtkbase.gtk_widget_set_rc_style(self._o)
+		_gtk.gtk_widget_set_rc_style(self._o)
 	def set_uposition(self, x, y):
-		_gtkbase.gtk_widget_set_uposition(self._o, x, y)
+		_gtk.gtk_widget_set_uposition(self._o, x, y)
 	def set_usize(self, w, h):
-		_gtkbase.gtk_widget_set_usize(self._o, w, h)
+		_gtk.gtk_widget_set_usize(self._o, w, h)
 	def shape_combine_mask(self, mask, ofs_x, ofs_y):
 		if hasattr(mask, '_o'):
 			tmp, mask = mask.get()
-	        _gtkbase.gtk_widget_shape_combine_mask(self._o, mask, ofs_x, ofs_y)
+	        _gtk.gtk_widget_shape_combine_mask(self._o, mask, ofs_x, ofs_y)
 	def show(self, obj=None):
-		_gtkbase.gtk_widget_show(self._o)
+		_gtk.gtk_widget_show(self._o)
 	def show_all(self, obj=None):
-		_gtkbase.gtk_widget_show_all(self._o)
+		_gtk.gtk_widget_show_all(self._o)
 	def show_now(self, obj=None):
-	        _gtkbase.gtk_widget_show_now(self._o)
+	        _gtk.gtk_widget_show_now(self._o)
 	def size_allocate(self, a):
-		_gtkbase.gtk_widget_size_allocate(self._o, a)
+		_gtk.gtk_widget_size_allocate(self._o, a)
 	def size_request(self):
-		return _gtkbase.gtk_widget_size_request(self._o)
+		return _gtk.gtk_widget_size_request(self._o)
 	def thaw_accelerators(self):
-		_gtkbase.gtk_widget_thaw_accelerators(self._o)
+		_gtk.gtk_widget_thaw_accelerators(self._o)
 	def unmap(self, obj=None):
-		_gtkbase.gtk_widget_unmap(self._o)
+		_gtk.gtk_widget_unmap(self._o)
 	def unparent(self):
-		_gtkbase.gtk_widget_unparent(self._o)
+		_gtk.gtk_widget_unparent(self._o)
 	def unrealize(self, obj=None):
-		_gtkbase.gtk_widget_unrealize(self._o)
+		_gtk.gtk_widget_unrealize(self._o)
 	
 class GtkContainer(GtkWidget):
-	get_type = _gtkbase.gtk_container_get_type
+	get_type = _gtk.gtk_container_get_type
 	def __init__(self, _obj=None):
 		if _obj: self._o = _obj; return
 	def add(self, child, **args):
 		if args == {}:
-			_gtkbase.gtk_container_add(self._o, child._o)
+			_gtk.gtk_container_add(self._o, child._o)
 		else:
-			_gtkbase.gtk_container_add(self._o, child._o, args)
+			_gtk.gtk_container_add(self._o, child._o, args)
 	def border_width(self, bw):
-		_gtkbase.gtk_container_border_width(self._o, bw)
+		_gtk.gtk_container_border_width(self._o, bw)
 	def check_resize(self):
-		_gtkbase.gtk_container_check_resize(self._o)
+		_gtk.gtk_container_check_resize(self._o)
 	def child_set(self, child, **args):
-		_gtkbase.gtk_container_child_set(self._o, child._o, args)
+		_gtk.gtk_container_child_set(self._o, child._o, args)
 	def child_get(self, child, arg):
-		return _gtkbase.gtk_container_child_get(self._o, child._o, arg)
+		return _gtk.gtk_container_child_get(self._o, child._o, arg)
 	def children(self):
-		l =  _gtkbase.gtk_container_children(self._o)
+		l =  _gtk.gtk_container_children(self._o)
 		return map(_obj2inst, l)
 	def child_type(self):
-		return _gtkbase.gtk_container_child_type(self._o)
+		return _gtk.gtk_container_child_type(self._o)
 	def focus(self, d):
-		_gtkbase.gtk_container_focus(self._o, d)
+		_gtk.gtk_container_focus(self._o, d)
 	def foreach(self, f):
 		for child in self.children():
 			f(child)
 	def register_toplevel(self):
-		_gtkbase.gtk_container_register_toplevel(self._o)
+		_gtk.gtk_container_register_toplevel(self._o)
 	def remove(self, child):
-		_gtkbase.gtk_container_remove(self._o, child._o)
+		_gtk.gtk_container_remove(self._o, child._o)
 	def resize_children(self):
-		_gtkbase.gtk_container_resize_children(self._o)
+		_gtk.gtk_container_resize_children(self._o)
 	def set_focus_child(self, child):
-		_gtkbase.gtk_container_set_focus_child(self._o, child._o)
+		_gtk.gtk_container_set_focus_child(self._o, child._o)
 	def set_focus_vadjustment(self, adj):
-		_gtkbase.gtk_container_set_focus_vadjustment(self._o, adj._o)
+		_gtk.gtk_container_set_focus_vadjustment(self._o, adj._o)
 	def set_focus_hadjustment(self, adj):
-		_gtkbase.gtk_container_set_focus_hadjustment(self._o, adj._o)
+		_gtk.gtk_container_set_focus_hadjustment(self._o, adj._o)
 	def set_resize_mode(self, mode):
-		_gtkbase.gtk_container_set_resize_mode(self._o, mode)
+		_gtk.gtk_container_set_resize_mode(self._o, mode)
 	def unregister_toplevel(self):
-		_gtkbase.gtk_container_unregister_toplevel(self._o)
+		_gtk.gtk_container_unregister_toplevel(self._o)
 
 class GtkBin(GtkContainer):
 	get_type = _gtk.gtk_bin_get_type
@@ -437,7 +479,8 @@ class GtkToggleButton(GtkButton):
 			self._o = _gtk.gtk_toggle_button_new_with_label(label)
 	def __getattr__(self, attr):
 	    attrs = {
-		    'active': _gtk.gtk_toggle_button_get_active
+		    'active': _gtk.gtk_toggle_button_get_active,
+		    'draw_indicator':_gtk.gtk_toggle_button_get_draw_indicator,
 	    }
 	    if attrs.has_key(attr):
 		    return attrs[attr](self._o)
@@ -583,6 +626,12 @@ class GtkRadioMenuItem(GtkCheckMenuItem):
 				self._o=_gtk.gtk_radio_menu_item_new_with_label(
 					group._o, label)
 
+class GtkTearoffMenuItem(GtkMenuItem):
+	get_type = _gtk.gtk_tearoff_menu_item_get_type
+	def __init__(self, _obj=None):
+		if _obj: self._o = _obj; return
+		self._o = _gtk.gtk_tearoff_menu_item_new()
+
 class GtkListItem(GtkItem):
 	get_type = _gtk.gtk_list_item_get_type
 	def __init__(self, label=None, _obj=None):
@@ -637,38 +686,40 @@ class GtkViewport(GtkBin):
 		_gtk.gtk_viewport_set_shadow_type(self._o, tp)
 
 class GtkWindow(GtkBin):
-	get_type = _gtkbase.gtk_window_get_type
+	get_type = _gtk.gtk_window_get_type
 	def __init__(self, type=WINDOW_TOPLEVEL, title=None, _obj=None):
 		if _obj: self._o = _obj; return
-		self._o = _gtkbase.gtk_window_new(type)
+		self._o = _gtk.gtk_window_new(type)
 		if title is not None:
 			self.set_title(title)
 	def activate_focus(self, obj=None):
-		_gtkbase.gtk_window_activate_focus(self._o)
+		_gtk.gtk_window_activate_focus(self._o)
 	def activate_default(self, obj=None):
-		_gtkbase.gtk_window_activate_default(self._o)
+		_gtk.gtk_window_activate_default(self._o)
 	def set_title(self, title):
-		_gtkbase.gtk_window_set_title(self._o, title)
+		_gtk.gtk_window_set_title(self._o, title)
 	def set_focus(self, focus):
-		_gtkbase.gtk_window_set_foxus(self._o, focus._o)
+		_gtk.gtk_window_set_focus(self._o, focus._o)
 	def set_default(self, defaultw):
-		_gtkbase.gtk_window_set_default(self._o, defaultw._o)
+		_gtk.gtk_window_set_default(self._o, defaultw._o)
 	def set_policy(self, as, ag, autos):
-		_gtkbase.gtk_window_set_policy(self._o, as, ag, autos)
+		_gtk.gtk_window_set_policy(self._o, as, ag, autos)
 	def add_accel_group(self, group):
-		_gtkbase.gtk_window_add_accel_group(self._o, group._ag)
+		_gtk.gtk_window_add_accel_group(self._o, group._ag)
 	def remove_accel_group(self, group):
-		_gtkbase.gtk_window_remove_accel_group(self._o, group._ag)
+		_gtk.gtk_window_remove_accel_group(self._o, group._ag)
 	def position(self, pos):
-		_gtkbase.gtk_window_position(self._o, pos)
+		_gtk.gtk_window_position(self._o, pos)
 	def set_wmclass(self, wmc_name, wmc_class):
-		_gtkbase.gtk_window_set_wmclass(self._o, wmc_name, wmc_class)
+		_gtk.gtk_window_set_wmclass(self._o, wmc_name, wmc_class)
 	def set_icon(self, pixmap, mask=None):
 		if not mask and hasattr(pixmap, '_o'):
 			pixmap, mask = pixmap.get()
-		_gtkbase.gtk_window_set_icon(self._o, pixmap, mask)
+		_gtk.gtk_window_set_icon(self._o, pixmap, mask)
 	def set_icon_name(self, name):
-		_gtkbase.gtk_window_set_icon_name(self._o, name)
+		_gtk.gtk_window_set_icon_name(self._o, name)
+	def set_modal(self, modal):
+		_gtk.gtk_window_set_modal(slef._o, modal)
 
 class GtkColorSelectionDialog(GtkWindow):
 	get_type = _gtk.gtk_color_selection_dialog_get_type
@@ -708,10 +759,6 @@ class GtkFileSelection(GtkWindow):
 		if _obj: self._o = _obj; return
 		self._o = _gtk.gtk_file_selection_new(title)
 
-	def set_filename(self, filename):
-		_gtk.gtk_file_selection_set_filename(self._o, filename)
-	def get_filename(self):
-		return _gtk.gtk_file_selection_get_filename(self._o)
 	def __getattr__(self, attr):
 		attrs = {
 		'cancel_button':   _gtk.gtk_file_selection_get_cancel_button,
@@ -725,6 +772,12 @@ class GtkFileSelection(GtkWindow):
 		}
 		if not attrs.has_key(attr): raise AttributeError, attr
 		return _obj2inst(attrs[attr](self._o))
+	def set_filename(self, filename):
+		_gtk.gtk_file_selection_set_filename(self._o, filename)
+	def get_filename(self):
+		return _gtk.gtk_file_selection_get_filename(self._o)
+	def complete(self):
+		_gtk.gtk_file_selection_complete(self._o)
 	def show_fileop_buttons(self):
 		_gtk.gtk_file_selection_show_fileop_buttons(self._o)
 	def hide_fileop_buttons(self):
@@ -735,6 +788,14 @@ class GtkInputDialog(GtkWindow):
 	def __init__(self, _obj=None):
 		if _obj: self._o = _obj; return
 		self._o = _gtk.gtk_input_dialog_new()
+	def __getattr__(self, attr):
+		attrs = {
+			'close_button': _gtk.gtk_input_dialog_get_close_button,
+			'save_button': _gtk.gtk_input_dialog_get_save_button
+		}
+		if attrs.has_key(attr):
+			return _obj2inst(attrs[attr](self._o))
+		raise AttributeError, attr
 
 class GtkFontSelectionDialog(GtkWindow):
 	get_type = _gtk.gtk_font_selection_dialog_get_type
@@ -860,6 +921,18 @@ class GtkGammaCurve(GtkVBox):
 	def __init__(self, _obj=None):
 		if _obj: self._o = _obj; return
 		self._o = _gtk.gtk_gamma_curve_new()
+	def __getattr__(self, attr):
+		if attr == 'gamma':
+			return _gtk.gtk_gamma_curve_get_gamma(self._o)
+		attrs = {
+			'curve': _gtk.gtk_gamma_curve_get_curve,
+			'gamma_dialog': _gtk.gtk_gamma_curve_get_gamma_dialog,
+			'gamma_text': _gtk.gtk_gamma_curve_get_gamma_text,
+			'table': _gtk.gtk_gamma_curve_get_table,
+		}
+		if attrs.has_key(attr):
+			return _obj2inst(attrs[attr](self._o))
+		raise AttributeError, attr
 
 class GtkButtonBox(GtkBox):
 	get_type = _gtk.gtk_button_box_get_type
@@ -954,38 +1027,60 @@ class GtkCList(GtkContainer):
 		return _gtk.gtk_clist_find_row_from_data(self._o, data)
 	def freeze(self, obj=None):
 		_gtk.gtk_clist_freeze(self._o)
+	def get_cell_style(self, row, col):
+		return _gtk.gtk_clist_get_cell_style(self._o, row, col)
 	def get_cell_type(self, r, c):
 		return _gtk.gtk_clist_get_cell_type(self._o, r, c)
 	def get_row_data(self, row):
 		return _gtk.gtk_clist_get_row_data(self._o, row)
+	def get_row_style(self, row):
+		return _gtk.gtk_clist_get_row_style(self._o, row)
 	def get_text(self, r, c):
 		return _gtk.gtk_clist_get_text(self._o, r, c)
 	def get_pixmap(self, r, c):
 		return _gtk.gtk_clist_get_pixmap(self._o, r, c)
 	def get_pixtext(self, r, c):
 		return _gtk.gtk_clist_get_pixtext(self._o, r, c)
+	def get_selectable(self, row):
+		return _gtk.gtk_clist_get_selectable(self._o, row)
 	def get_selection_info(self, x, y):
 		return _gtk.gtk_clist_get_selection_info(self._o, x, y)
 	def insert(self, row, values):
-		_gtk.gtk_clist_insert(self._o, row, values)
+		return _gtk.gtk_clist_insert(self._o, row, values)
 	def moveto(self, row=-1, col=-1, row_align=0.5, col_align=0.5):
 		_gtk.gtk_clist_moveto(self._o, row, col, row_align, col_align)
+	def optimal_column_width(self, col):
+		return _gtk.gtk_clist_optimal_column_width(self._o, col)
 	def remove(self, row):
 		_gtk.gtk_clist_remove(self._o, row)
+	def row_is_visible(self, row):
+		return _gtk.gtk_clist_row_is_visible(self._o, row)
 	def select_all(self):
 		_gtk.gtk_clist_select_all(self._o)
 	def select_row(self, row, col):
 		_gtk.gtk_clist_select_row(self._o, row, col)
+	def set_auto_sort(self, auto_sort):
+		_gtk.gtk_clist_set_auto_sort(self._o, auto_sort)
 	def set_background(self, row, colour):
 		_gtk.gtk_clist_set_background(self._o, row, colour)
-	def set_border(self, border):
-		_gtk.gtk_clist_set_border(self._o, border)
-	def set_column_title(self, col, title):
-		_gtk.gtk_clist_set_column_title(self._o, col, title)
-	def set_column_widget(self, col, w):
-		_gtk.gtk_clist_set_column_widget(self._o, col, w._o)
+	def set_cell_style(self, row, col, style):
+		_gtk.gtk_clist_set_cell_style(self._o, row, col, style)
+	def set_column_auto_resize(self, col, auto):
+		_gtk.gtk_clist_set_column_auto_resize(self._o, col, auto)
 	def set_column_justification(self, col, just):
 		_gtk.gtk_clist_set_column_justification(self._o, col, just)
+	def set_column_max_width(self, col, width):
+		_gtk.gtk_clist_set_column_max_width(self._o, col, width)
+	def set_column_min_width(self, col, width):
+		_gtk.gtk_clist_set_column_min_width(self._o, col, width)
+	def set_column_resizeable(self, col, resizeable):
+		_gtk.gtk_clist_set_column_resizeable(self._o, col, resizeable)
+	def set_column_title(self, col, title):
+		_gtk.gtk_clist_set_column_title(self._o, col, title)
+	def set_column_visibility(self, col, visible):
+		_gtk.gtk_clist_set_column_visibility(self._o, col, visible)
+	def set_column_widget(self, col, w):
+		_gtk.gtk_clist_set_column_widget(self._o, col, w._o)
 	def set_column_width(self, col, width):
 		_gtk.gtk_clist_set_column_width(self._o, col, width)
 	def set_foreground(self, row, colour):
@@ -996,10 +1091,20 @@ class GtkCList(GtkContainer):
 		_gtk.gtk_clist_set_row_data(self._o, row, data)
 	def set_row_height(self, height):
 		_gtk.gtk_clist_set_row_height(self._o, height)
+	def set_row_style(self, row, style):
+		_gtk.gtk_clist_set_row_style(self._o, row, style)
 	def set_shift(self, row, col, v, h):
 		_gtk.gtk_clist_set_shift(self._o, row, col, v, h)
+	def set_selectable(self, row, selectable):
+		_gtk.gtk_clist_set_selectable(self._o, row, selectable)
 	def set_selection_mode(self, mode):
 		_gtk.gtk_clist_set_selection_mode(self._o, mode)
+	def set_shadow_type(self, border):
+		_gtk.gtk_clist_set_shadow_type(self._o, border)
+	def set_sort_column(self, col):
+		_gtk.gtk_clist_set_sort_column(self._o, col)
+	def set_sort_type(self, sort_type):
+		_gtk.gtk_clist_set_sort_type(self._o, sort_type)
 	def set_text(self, r, c, text):
 		_gtk.gtk_clist_set_text(self._o, r, c, text)
 	def set_pixmap(self, r, c, pixmap, mask=None):
@@ -1011,6 +1116,8 @@ class GtkCList(GtkContainer):
 			pixmap, mask = pixmap.get()
 		_gtk.gtk_clist_set_pixtext(self._o, r, c, text, spacing,
 					   pixmap, mask)
+	def sort(self):
+		_gtk.gtk_clist_sort(self._o)
 	def swap_rows(self, row1, row2):
 		_gtk.gtk_clist_swap_rows(self._o, row1, row2)
 	def thaw(self):
@@ -1102,6 +1209,11 @@ class GtkMenuShell(GtkContainer):
 		_gtk.gtk_menu_shell_insert(self._o, child._o, pos)
 	def deactivate(self, obj=None):
 		_gtk.gtk_menu_shell_deactivate(self._o)
+	def select_item(self, item):
+		_gtk.gtk_menu_shell_select_item(self._o, item._o)
+	def activate_item(self, item, force_deactivate):
+		_gtk.gtk_menu_shell_activate_item(self._o, item._o,
+						  force_deactivate)
 
 class GtkMenuBar(GtkMenuShell):
 	get_type = _gtk.gtk_menu_bar_get_type
@@ -1142,6 +1254,8 @@ class GtkMenu(GtkMenuShell):
 		_gtk.gtk_menu_set_active(self._o, index)
 	def set_accel_group(self, group):
 		_gtk.gtk_menu_set_accel_group(self._o, group._ag)
+	def set_tearoff_state(self, torn_off):
+		_gtk.gtk_menu_set_tearoff_state(self._o, torn_off)
 
 class GtkNotebook(GtkContainer):
 	get_type = _gtk.gtk_notebook_get_type
@@ -1167,6 +1281,8 @@ class GtkNotebook(GtkContainer):
 		_gtk.gtk_notebook_remove_page(self._o, pos)
 	def current_page(self):
 		return _gtk.gtk_notebook_current_page(self._o)
+	def page_num(self, child):
+		return _gtk.gtk_notebook_page_num(self._o, child._o)
 	def set_page(self, pos):
 		_gtk.gtk_notebook_set_page(self._o, pos)
 	def next_page(self, obj=None):
@@ -1177,6 +1293,8 @@ class GtkNotebook(GtkContainer):
 		_gtk.gtk_notebook_reorder_child(self._o, child._o, pos)
 	def set_tab_border(self, border):
 		_gtk.gtk_notebook_set_tab_border(self._o, border)
+	def get_tab_pos(self):
+		return _gtk.gtk_notebook_get_tab_pos(self._o)
 	def set_tab_pos(self, pos):
 		_gtk.gtk_notebook_set_tab_pos(self._o, pos)
 	def set_scrollable(self, scrollable):
@@ -1495,8 +1613,6 @@ class GtkEntry(GtkEditable):
 		_gtk.gtk_entry_set_visibility(self._o, visible)
 	def set_editable(self, editable):
 		_gtk.gtk_entry_set_editable(self._o, editable)
-	def adjust_scroll(self):
-		_gtk.gtk_entry_adjust_scroll(self._o)
 	def set_max_length(self, max):
 		_gtk.gtk_entry_set_max_length(self._o, max)
 
@@ -1548,12 +1664,14 @@ class GtkText(GtkEditable):
 		_gtk.gtk_text_set_editable(self._o, editable)
 	def set_word_wrap(self, word_wrap):
 		_gtk.gtk_text_set_word_wrap(self._o, word_wrap)
+	def set_line_wrap(self, line_wrap):
+		_gtk.gtk_text_set_line_wrap(self._o, line_wrap)
 	def set_adjustments(self, hadj, vadj):
 		_gtk.gtk_text_set_adjustments(self._o, hadj._o, vadj._o)
 	def get_hadjustment(self):
-		return _obj2inst(_gtk.gtk_text_get_hadjustment(self._o))
+		return _obj2inst(_gtk.gtk_text_get_hadj(self._o))
 	def get_vadjustment(self):
-		return _obj2inst(_gtk.gtk_text_get_vadjustment(self._o))
+		return _obj2inst(_gtk.gtk_text_get_vadj(self._o))
 	def set_point(self, point):
 		_gtk.gtk_text_set_point(self._o, point)
 	def get_point(self):
@@ -1591,12 +1709,6 @@ class GtkArrow(GtkMisc):
 	def set(self, at, st):
 		_gtk.gtk_arrow_set(self._o, at, st)
 
-class GtkImage(GtkMisc):
-	get_type = _gtk.gtk_image_get_type
-	def __init__(self, _obj=None):
-		if _obj: self._o = _obj; return
-	# XXX should have __init__, set, get
-
 class GtkPixmap(GtkMisc):
 	get_type = _gtk.gtk_pixmap_get_type
 	def __init__(self, parent_or_pixmap=None, xpm_or_mask=None, bg=None,
@@ -1628,8 +1740,12 @@ class GtkLabel(GtkMisc):
 		_gtk.gtk_label_set(self._o, str)
 	def set_justify(self, jtype):
 		_gtk.gtk_label_set_justify(self._o, jtype)
+	def set_pattern(self, pattern):
+		_gtk.gtk_label_set_pattern(self._o, pattern)
 	def get(self):
 		return _gtk.gtk_label_get(self._o)
+	def parse_uline(self, string):
+		return _gtk.gtk_label_parse_uline(self._o, string)
 
 class GtkAccelLabel(GtkLabel):
 	get_type = _gtk.gtk_accel_label_get_type
@@ -1679,6 +1795,8 @@ class GtkPreview(GtkWidget):
 		_gtk.gtk_preview_set_install_cmap(install)
 	def set_reserved(self, reserved):
 		_gtk.gtk_preview_set_reserved(reserved)
+	def set_dither(self, dither):
+		_gtk.gtk_preview_set_dither(self._o, dither)
 
 class GtkProgress(GtkWidget):
 	get_type = _gtk.gtk_progress_get_type
@@ -1862,29 +1980,29 @@ del m
 class GtkAccelGroup:
 	def __init__(self, _obj=None):
 		if _obj: self._ag = _obj; return
-		self._ag = _gtkbase.gtk_accel_group_new()
+		self._ag = _gtk.gtk_accel_group_new()
 	def activate(self, key, mods):
-		_gtkbase.gtk_accel_group_activate(self._ag, key, mods)
+		_gtk.gtk_accel_group_activate(self._ag, key, mods)
 	def attach(self, obj):
-		_gtkbase.gtk_accel_group_attach(self._ag, obj._o)
+		_gtk.gtk_accel_group_attach(self._ag, obj._o)
 	def detach(self, obj):
-		_gtkbase.gtk_accel_group_detach(self._ag, obj._o)
+		_gtk.gtk_accel_group_detach(self._ag, obj._o)
 	def lock(self):
-		_gtkbase.gtk_accel_group_lock(self._ag)
+		_gtk.gtk_accel_group_lock(self._ag)
 	def unlock(self):
-		_gtkbase.gtk_accel_group_unlock(self._ag)
+		_gtk.gtk_accel_group_unlock(self._ag)
 	def lock_entry(self, key, mods):
-		_gtkbase.gtk_accel_group_lock_entry(self._ag, key, mods)
+		_gtk.gtk_accel_group_lock_entry(self._ag, key, mods)
 	def unlock_entry(self, key, mods):
-		_gtkbase.gtk_accel_group_unlock_entry(self._ag, key, mods)
+		_gtk.gtk_accel_group_unlock_entry(self._ag, key, mods)
 	def add(self, key, mods, flags, obj, signal):
-		_gtkbase.gtk_accel_group_add(self._ag, key, mods, flags,
+		_gtk.gtk_accel_group_add(self._ag, key, mods, flags,
 					 obj._o, signal)
 	def remove(self, key, mods, obj):
-		_gtkbase.gtk_accel_group_remove(self._ag, key, mods, obj._o)
+		_gtk.gtk_accel_group_remove(self._ag, key, mods, obj._o)
 
 def _obj2inst(obj):
-	objname = _gtkbase.gtk_type_name(_gtkbase.GTK_OBJECT_TYPE(obj))
+	objname = _gtk.gtk_type_name(_gtk.GTK_OBJECT_TYPE(obj))
 	if _name2cls.has_key(objname):
 		return _name2cls[objname](_obj=obj)
 	# if I don't know what the object is, guess
@@ -1904,7 +2022,7 @@ def _obj2inst(obj):
 def _filtprops(props):
 	for k in props.keys():
 		v = props[k]
-		if hasattr(v, '_o') and type(v._o) == _gtkbase.GtkObjectType:
+		if hasattr(v, '_o') and type(v._o) == _gtk.GtkObjectType:
 			props[k] = v._o
 
 def new(tp, **props):
@@ -1915,33 +2033,35 @@ def new(tp, **props):
 	elif type(tp) != type(0):
 		raise TypeError, "unknow type argument: " + tp
 	_filtprops(props)
-	return _obj2inst(_gtkbase.gtk_object_new(tp, props))
+	return _obj2inst(_gtk.gtk_object_new(tp, props))
 
 # flow control
 def mainloop():
-	_gtkbase.gtk_main()
+	_gtk.gtk_main()
 def mainquit(*args):
-	_gtkbase.gtk_main_quit()
+	_gtk.gtk_main_quit()
 def mainiteration(block=TRUE):
-	_gtkbase.gtk_main_iteration(block)
+	return _gtk.gtk_main_iteration(block)
+def events_pending():
+	return _gtk.gtk_events_pending()
 
 # idle/quit/timeout handlers
 def idle_add(callback):
-	return _gtkbase.gtk_idle_add(callback)
+	return _gtk.gtk_idle_add(callback)
 def idle_add_priority(priority, callback):
-	return _gtkbase.gtk_idle_add_priority(priority, callback)
+	return _gtk.gtk_idle_add_priority(priority, callback)
 def idle_remove(tag):
-	_gtkbase.gtk_idle_remove(tag)
+	_gtk.gtk_idle_remove(tag)
 def quit_add(mainlevel, callback):
-        return _gtkbase.gtk_quit_add(mainlevel, callback)
+        return _gtk.gtk_quit_add(mainlevel, callback)
 def quit_add_destroy(mainlevel, object):
-	_gtkbase.gtk_quit_add_destroy(mainlevel, object._o)
+	_gtk.gtk_quit_add_destroy(mainlevel, object._o)
 def quit_remove(tag):
-	_gtkbase.gtk_quit_remove(tag)
+	_gtk.gtk_quit_remove(tag)
 def timeout_add(timeout, callback):
-	return _gtkbase.gtk_timeout_add(timeout, callback)
+	return _gtk.gtk_timeout_add(timeout, callback)
 def timeout_remove(tag):
-	_gtkbase.gtk_timeout_remove(tag)
+	_gtk.gtk_timeout_remove(tag)
 
 # input (file handle) handler
 def input_add(source, condition, callback):
@@ -1949,23 +2069,27 @@ def input_add(source, condition, callback):
 		# handle python file handles
 		def wrapper(source, condition, real_s=source,real_cb=callback):
 			real_cb(real_s, condition)
-		return _gtkbase.gtk_input_add(source.fileno(), condition, wrapper)
+		return _gtk.gtk_input_add(source.fileno(), condition, wrapper)
 	else:
-		return _gtkbase.gtk_input_add(source, condition, callback)
+		return _gtk.gtk_input_add(source, condition, callback)
 def input_remove(tag):
-	_gtkbase.gtk_input_remove(tag)
+	_gtk.gtk_input_remove(tag)
 
 # these functions govern modality
 def grab_add(wid):
-	_gtkbase.gtk_grab_add(wid._o)
+	_gtk.gtk_grab_add(wid._o)
 def grab_remove(wid):
-	_gtkbase.gtk_grab_remove(wid._o)
+	_gtk.gtk_grab_remove(wid._o)
+def grab_get_current():
+	return _obj2inst(_gtk.gtk_grab_get_current())
 
 # RC parsing
 def rc_parse(fname):
-	_gtkbase.gtk_rc_parse(fname)
+	_gtk.gtk_rc_parse(fname)
 def rc_parse_string(string):
-	_gtkbase.gtk_rc_parse_string(string)
+	_gtk.gtk_rc_parse_string(string)
+def rc_reparse_all():
+	_gtk.gtk_rc_repase_all()
 
 # font loading
 def load_font(font):
@@ -1973,8 +2097,15 @@ def load_font(font):
 def load_fontset(fontset):
 	return _gtk.gdk_fontset_load(fontset)
 
+# cursor loading
+def cursor_new(type):
+	return _gtk.gdk_cursor_new(type)
+def cursor_new_from_pixmap(source, mask, fg, bg, x, y):
+	return _gtk.gdk_cursor_new_from_pixmap(source, mask, fg, bg, x, y)
+
 # colour allocation
 def colour_alloc(parent, red, green=None, blue=None):
+	print "colour_alloc deprecated.  Use GdkColormap.alloc"
 	if hasattr(parent, '_o'): cmap = parent.get_window().colormap
 	elif hasattr(parent, 'colormap'): cmap = parent.colormap
 	else: cmap = parent
@@ -1993,12 +2124,24 @@ def colour_alloc(parent, red, green=None, blue=None):
 # This one's for the Americans...
 color_alloc = colour_alloc
 
+# atoms ...
+def atom_intern(name, only_if_exists=FALSE):
+	return _gtk.gdk_atom_intern(name, only_if_exists)
+def atom_name(atom):
+	return _gtk.gdk_atom_name(atom)
+
 # pixmap loading
 def create_pixmap_from_xpm(window, bg, xpm):
 	if hasattr(window, '_o'):
 		window.realize()
 		window = window.get_window()
 	return _gtk.gdk_pixmap_create_from_xpm(window, bg, xpm)
+# use XPM data ...
+def create_pixmap_from_xpm_d(window, bg, xpm_d):
+	if hasattr(window, '_o'):
+		window.realize()
+		window = window.get_window()
+	return _gtk.gdk_pixmap_create_from_xpm_d(window, bg, xpm_d)
 def create_pixmap(window, width, height, depth=-1):
 	if (hasattr(window, '_o')):
 	        window.realize()
