@@ -40,12 +40,45 @@ class GtkStyle:
 	text_gc = (_, _, _, _, _)
 	base_gc = (_, _, _, _, _)
 
-	"""Tjese are background pixmaps for the various states"""
+	"""These are background pixmaps for the various states"""
 	bg_pixmap = (_, _, _, _, _)
 
 	"""The colormap for this style"""
 	colormap = _
 
+class GtkSelectionData:
+	"""This type represents the selection.  Do not keep a reference"""
+	"""to it past the life of a callback"""
+	"""The selection atom"""
+	selection = _
+	"""target atom"""
+	target = _
+	"""type atom"""
+	type = _
+	"""format type"""
+	format = _
+	"""The data in this selection"""
+	data = "some_data"
+	def set(self, type, format, data):
+		"""Set the type, format and data parts of the selection data"""
+		pass
+
+class GdkAtom:
+	"""This type represents a GdkAtom.  The reason for not using ints"""
+	"""is that this type can automatically coerce to int, long, float"""
+	"""or string, reducing the need for gdk_atom_intern/name in a lot"""
+	"""of cases.  Functions that take atoms as input are really reading"""
+	"""ints, and this type just gets coerced."""
+	def __int__(self): pass
+	def __long__(self): pass
+	def __float__(self): pass
+	def __oct__(self): pass
+	def __hex__(self): pass
+	def __coerce__(self, other):
+		"""will corece self to any of int, long, float or string if"""
+		"""other type matches, otherwise fail"""
+		pass
+
 class GdkColor:
 	"""These are the attributes of a GdkColor:"""
 	red   = _
@@ -74,6 +107,27 @@ class GdkColormap:
 		that has been allocated in the colormap"""
 		pass
 
+class GdkDragContext:
+	"""This event holds the context of a DND drag"""
+
+	"""The protocol"""
+	protocol = _
+	"""True if we are on the source end (I think)"""
+	is_source = _
+	"""source and destination windows"""
+	source_window = _
+	dest_window = _
+	"""A list of target atoms for this drag"""
+	targets = [_, _, _]
+	"""A combination of the GdkDragAction flags"""
+	actions = _
+	"""The suggested action atom"""
+	suggested_action = _
+	"""The action atom"""
+	action = _
+	"""The start time for the drag"""
+	start_time = _
+
 class GdkEvent:
 	"""The type of the event -- this decides on what other attributes the
 	object has"""
@@ -145,13 +199,19 @@ class GdkFont:
 	descent = _
 	""" the font type (GDK.FONT_FONT or GDK.FONT_FONTSET) """
 	type = _
-	def width(str):
+	def width(self, str):
 		"""return the width of the string"""
 		pass
-	def measure(str):
+	def height(self, str):
+		"""return the height of the string"""
+		pass
+	def measure(self, str):
 		"""return the width of the string, taking into account kerning
 		of the final character"""
 		pass
+	def extents(self, str):
+		"""return (lbearing,rbearing,width,ascent,descent)"""
+		pass
 
 
 class GdkGC:
@@ -193,14 +253,20 @@ class GdkWindow:
 	pointer = (_, _)
 	pointer_state = _
 
-	def new_gc(foreground=None, background=None, font=None, tile=None,
-		   stipple=None, clip_mask=None, function=None, fill=None,
-		   subwindow_mode=None, ts_x_origin=None, ts_y_origin=None,
-		   clip_x_origin=None, clip_y_origin=None, line_width=None,
-		   line_style=None, cap_style=None, join_style=None):
-		"""Creates a new GC for this window with the given settings.
-		The settings must be given as keyword arguments.  If a
-		setting isn't given, then its default will be used"""
+	def new_gc(self, foreground=None, background=None, font=None,
+		   tile=None, stipple=None, clip_mask=None,
+		   function=None, fill=None, subwindow_mode=None,
+		   ts_x_origin=None, ts_y_origin=None,
+		   clip_x_origin=None, clip_y_origin=None,
+		   line_width=None, line_style=None, cap_style=None,
+		   join_style=None):
+		"""Creates a new GC for this
+		window with the given settings.  The settings must
+		be given as keyword arguments.  If a setting isn't
+		given, then its default will be used"""
+		pass
+	def set_cursor(self, cursor):
+		"""Sets the cursor for this window"""
 		pass
 	
 """Aliases for GdkWindow.  GdkPixmap refers to an offscreen pixmap.
