@@ -205,6 +205,11 @@ def dialog_add(dlg, child, info):
 	# the widgets are already added
 	pass
 
+def menuitem_add(mi, menu, info):
+	mi.set_submenu(menu)
+def menushell_add(menu, mi, info):
+	menu.append(mi)
+
 def misc_set(misc, info):
 	xalign = info.get_float('xalign', 0.5)
 	yalign = info.get_float('yalign', 0.5)
@@ -394,9 +399,6 @@ def vscrollbar_new(node):
 	scroll = GtkVScrollbar(adj)
 	scroll.set_update_policy(node.get('policy', UPDATE_CONTINUOUS))
 	return scroll
-def menu_new(node):
-	# the menu component of glade is not finished
-	return GtkMenu()
 def statusbar_new(node):
 	return GtkStatusbar()
 def toolbar_new(node):
@@ -428,6 +430,37 @@ def hseparator_new(node):
 def vseparator_new(node):
 	return GtkVSeparator()
 
+def menubar_new(node):
+	return GtkMenuBar()
+def menu_new(node):
+	return GtkMenu()
+def menuitem_new(node):
+	if node.has_key('label'):
+		ret = GtkMenuItem(node.label)
+	else:
+		ret = GtkMenuItem()
+	if node.get_bool('right_justify', FALSE):
+		ret.right_justify()
+	return ret
+def checkmenuitem_new(node):
+	ret = GtkCheckMenuItem(node.label)
+	if node.get_bool('right_justify', FALSE):
+		ret.right_justify()
+	if node.get_bool('active', FALSE):
+		ret.set_state(TRUE)
+	if node.get_bool('always_show_toggle', FALSE):
+		ret.set_show_toggle(TRUE)
+	return ret
+def radiomenuitem_new(node):
+	ret = GtkRadioMenuItem(node.label)
+	if node.get_bool('right_justify', FALSE):
+		ret.right_justify()
+	if node.get_bool('active', FALSE):
+		ret.set_state(TRUE)
+	if node.get_bool('always_show_toggle', FALSE):
+		ret.set_show_toggle(TRUE)
+	return ret
+
 def hbox_new(node):
 	if node.has_key('child_name') and node.child_name[:7] == 'Dialog:':
 		return node.__wid
@@ -641,7 +674,6 @@ _widgets = {
 	'GtkVRuler':       (vruler_new,       None),
 	'GtkHScrollbar':   (hscrollbar_new,   None),
 	'GtkVScrollbar':   (vscrollbar_new,   None),
-	'GtkMenu':         (menu_new,         None),
 	'GtkStatusbar':    (statusbar_new,    None),
 	'GtkToolbar':      (toolbar_new,      None),
 	'GtkProgressBar':  (progressbar_new,  None),
@@ -651,6 +683,13 @@ _widgets = {
 	'GtkHSeparator':   (hseparator_new,   None),
 	'GtkVSeparator':   (vseparator_new,   None),
 
+	# Menu stuff ...
+	'GtkMenuBar':      (menubar_new,      menushell_add),
+	'GtkMenu':         (menu_new,         menushell_add),
+	'GtkMenuItem':     (menuitem_new,     menuitem_add),
+	'GtkCheckMenuItem':(checkmenuitem_new,menuitem_add),
+	'GtkRadioMenuItem':(radiomenuitem_new,menuitem_add),
+
 	# Containers ...
 	'GtkHBox':         (hbox_new,         box_add),
 	'GtkVBox':         (vbox_new,         box_add),
